diff --git a/Code/Mantid/MantidPlot/src/ApplicationWindow.cpp b/Code/Mantid/MantidPlot/src/ApplicationWindow.cpp
index 2107d3d..3f3b656 100644
--- a/Code/Mantid/MantidPlot/src/ApplicationWindow.cpp
+++ b/Code/Mantid/MantidPlot/src/ApplicationWindow.cpp
@@ -9555,6 +9555,9 @@ void ApplicationWindow::closeEvent( QCloseEvent* ce )
   m_scriptInterpreter->shutdown();
   scriptingEnv()->finalize();
 
+  // Help window
+  HelpWindow::Instance().hostShuttingDown();
+
   ce->accept();
 
 }
diff --git a/Code/Mantid/MantidQt/API/inc/MantidQtAPI/HelpWindow.h b/Code/Mantid/MantidQt/API/inc/MantidQtAPI/HelpWindow.h
index f317c34..905086e 100644
--- a/Code/Mantid/MantidQt/API/inc/MantidQtAPI/HelpWindow.h
+++ b/Code/Mantid/MantidQt/API/inc/MantidQtAPI/HelpWindow.h
@@ -19,6 +19,7 @@ public:
     void showAlgorithm(const std::string &name=std::string(), const int version=-1);
     void showAlgorithm(const QString &name, const int version=-1);
     void showFitFunction(const std::string &name=std::string());
+    void hostShuttingDown();
 
 private:
     friend struct Mantid::Kernel::CreateUsingNew<HelpWindowImpl>;
diff --git a/Code/Mantid/MantidQt/API/src/HelpWindow.cpp b/Code/Mantid/MantidQt/API/src/HelpWindow.cpp
index bc9ff56..301f6ed 100644
--- a/Code/Mantid/MantidQt/API/src/HelpWindow.cpp
+++ b/Code/Mantid/MantidQt/API/src/HelpWindow.cpp
@@ -114,6 +114,21 @@ void HelpWindowImpl::showFitFunction(const std::string &name)
 }
 
 /**
+ * Can be called by the host process to indicate that it will
+ * close soon. This closes the help window & releases the QProcess
+ */
+void HelpWindowImpl::hostShuttingDown()
+{
+  if(m_process)
+  {
+    m_process->kill();
+    // Delete
+    m_process.reset();
+  }
+}
+
+
+/**
  * Start up the help browser in a separate process.
  *
  * This will only do something if the browser is not already
